# REQ01 - Requirements Engineering

Quy trình kỹ thuật yêu cầu phần mềm: thu thập, phân tích, đặc tả và xác nhận yêu cầu.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Requirements Elicitation](REQ01-BP01-Requirements-Elicitation.md) | Kỹ thuật thu thập yêu cầu từ stakeholders |
| BP02 | [Requirements Analysis](REQ01-BP02-Requirements-Analysis.md) | Phân tích và làm rõ yêu cầu |
| BP03 | [Requirements Specification](REQ01-BP03-Requirements-Specification.md) | Đặc tả yêu cầu rõ ràng và đầy đủ |

## Tham khảo

- IEEE 830 - Software Requirements Specifications
- IREB - International Requirements Engineering Board
- BABOK - Business Analysis Body of Knowledge
